summaryrefslogtreecommitdiff
path: root/tools/gyp
diff options
context:
space:
mode:
authorisaacs <i@izs.me>2012-04-11 18:26:52 -0700
committerisaacs <i@izs.me>2012-04-11 18:26:52 -0700
commit04271a5e9394e6dadf6c5172bcfac1d5f086db8f (patch)
tree6076c1c0d03c03fa6ba0158680b5c3e429d00eeb /tools/gyp
parent1c88c3b3b56c6047180e116c5614dad2b13995f9 (diff)
downloadandroid-node-v8-04271a5e9394e6dadf6c5172bcfac1d5f086db8f.tar.gz
android-node-v8-04271a5e9394e6dadf6c5172bcfac1d5f086db8f.tar.bz2
android-node-v8-04271a5e9394e6dadf6c5172bcfac1d5f086db8f.zip
gyp: Apply 'argument too long' fix in another place
For some reason, aa5961a445acbd2b533ef870eb19733be7b7ede5 caused 'make test' to rebuild the entire project every time. Applying the fix to the other place where gyp chops up the argument list makes it behave properly.
Diffstat (limited to 'tools/gyp')
-rw-r--r--tools/gyp/pylib/gyp/generator/make.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/gyp/pylib/gyp/generator/make.py b/tools/gyp/pylib/gyp/generator/make.py
index 3b01a8d861..ec05190814 100644
--- a/tools/gyp/pylib/gyp/generator/make.py
+++ b/tools/gyp/pylib/gyp/generator/make.py
@@ -2128,10 +2128,10 @@ def GenerateOutput(target_list, target_dicts, data, params):
if generator_flags.get('auto_regeneration', True):
WriteAutoRegenerationRule(params, root_makefile, makefile_name, build_files)
# Write the rule to load dependencies. We batch 1000 files at a time to
# avoid overflowing the command line.
all_deps = ""
- for i in range(1001, num_outputs, 1000):
+ for i in range(513, num_outputs, 512):
all_deps += ("""
ifneq ($(word %(start)d,$(d_files)),)
$(shell cat $(wordlist %(start)d,%(end)d,$(d_files)) >> $(depsdir)/all.deps)
@@ -2142,7 +2142,7 @@ def GenerateOutput(target_list, target_dicts, data, params):
ifneq ($(word %(last)d,$(d_files)),)
$(error Found unprocessed dependency files (gyp didn't generate enough rules!))
endif
-""" % { 'last': ((num_outputs / 1000) + 1) * 1000 + 1 }
+""" % { 'last': ((num_outputs / 512) + 1) * 512 + 1 }
root_makefile.write(SHARED_FOOTER % { 'generate_all_deps': all_deps })
@@ -2128,10 +2128,10 @@ def GenerateOutput(target_list, target_dicts, data, params):
if generator_flags.get('auto_regeneration', True):
WriteAutoRegenerationRule(params, root_makefile, makefile_name, build_files)
- # Write the rule to load dependencies. We batch 1000 files at a time to
+ # Write the rule to load dependencies. We batch 512 files at a time to
# avoid overflowing the command line.
all_deps = ""